==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libconnection/async_text_created.cc <==
// Objects for handling the asynchronous message "New text created"
//
// $Id: async_text_created.cc,v 1.1 1994/08/05 21:58:07 inge Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <assert.h>
#include <stdlib.h>
#include "async_text_created.h"
#include "prot-a-LyStr.h"
#include "connection.h"


Async_text_created::Async_text_created()
: tstat()
{
}

Async_text_created::Async_text_created(const Async_text_created &t)
    : tstat(t.tstat)
{
}

Async_text_created::~Async_text_created()
{
}

Async_text_created &
Async_text_created::operator =(const Async_text_created &t)
{
    tstat = t.tstat;
    return *this;
}

Text_stat 
Async_text_created::text_stat() const
{
    return tstat;
}

Async_text_created::Async_text_created(prot_a_LyStr &p)
{
    Text_no tno = p.stol();
    Text_stat t(tno, p);
    tstat = t;
}


// ================================================================
//         Async_text_created_administrator methods


Async_text_created_administrator::
Async_text_created_administrator(Async_storage *as)
  : Async_administrator(as)
{
}

Async_text_created_administrator::~Async_text_created_administrator()
{
}

void *
Async_text_created_administrator::register_handler(void *userdata, 
						   Handlerp hnd)
{
    return Async_administrator::register_handler(userdata, (void*)hnd, 
						 ASYNC_NEW_TEXT);
}


void
Async_text_created_administrator::unregister_handler(void* hnd)
{
    Async_administrator::unregister_handler(hnd);
}


const Async_message *
Async_text_created_administrator::parse(prot_a_LyStr &msg) const
{
    return new Async_text_created(msg);
}


void 
Async_text_created_administrator::handle_message(const Async_message *msg)
{
    for (struct Hinfo* ptr = handler_list_head();
	 ptr != NULL;
	 ptr = ptr->next)
    {
	Async_text_created *m = (Async_text_created*)msg;
	(*(Handlerp)ptr->handle)(ptr->userdata, *m);
    }
}

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libconnection/async_text_created.cc <==
// Objects for handling the asynchronous message "New text created"
//
// $Id: async_text_created.cc,v 1.3 1995/11/14 06:06:32 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <assert.h>
#include <stdlib.h>
#include "async_text_created.h"
#include "prot-a-LyStr.h"
#include "connection.h"


Async_text_created::Async_text_created()
: tstat()
{
}

Async_text_created::Async_text_created(const Async_text_created &t)
    : tstat(t.tstat)
{
}

Async_text_created::~Async_text_created()
{
}

Async_text_created &
Async_text_created::operator =(const Async_text_created &t)
{
    tstat = t.tstat;
    return *this;
}

Async_name
Async_text_created::name()
{
    return ASYNC_NEW_TEXT;
}

Text_stat 
Async_text_created::text_stat() const
{
    return tstat;
}

Async_text_created::Async_text_created(prot_a_LyStr &p)
{
    Text_no tno = p.stol();
    Text_stat t(tno, p);
    tstat = t;
}

const Async_message *
Async_administrator<Async_text_created>::parse(prot_a_LyStr &in)
{
    return new Async_text_created(in);
}
